@@ -3,27 +3,26 @@
 
 import asyncio
 import logging
-import urllib.parse
 import weakref
 from datetime import timedelta
 from http import HTTPStatus
 from socket import AddressFamily  # pylint: disable=no-name-in-module
 from typing import Dict, Mapping, Optional, Tuple, Union
+from urllib.parse import urlparse
 
 import defusedxml.ElementTree as DET
 
 from async_upnp_client.client import UpnpRequester, UpnpService
 from async_upnp_client.const import NS
 from async_upnp_client.exceptions import (
+    UpnpConnectionError,
     UpnpError,
     UpnpResponseError,
     UpnpSIDError,
-    UpnpConnectionError,
 )
 from async_upnp_client.utils import async_get_local_ip, get_local_ip
 
 _LOGGER = logging.getLogger(__name__)
-_LOGGER_TRAFFIC_UPNP = logging.getLogger("async_upnp_client.traffic.upnp")
 
 
 class UpnpEventHandler:
@@ -54,9 +53,9 @@ class UpnpEventHandler:
         self.listen_ports = listen_ports or {}
 
         self._listen_ip: Optional[str] = None
-        self._subscriptions = (
-            weakref.WeakValueDictionary()
-        )  # type: weakref.WeakValueDictionary [str, UpnpService]
+        self._subscriptions: weakref.WeakValueDictionary[
+            str, UpnpService
+        ] = weakref.WeakValueDictionary()
         self._backlog: Dict[str, Tuple[Mapping, str]] = {}
 
     @property
@@ -90,7 +89,7 @@ class UpnpEventHandler:
 
         # Figure out how this host connects to the device, then infer how the
         # device can connect back
-        device_host = urllib.parse.urlparse(service.device.device_url).netloc
+        device_host = urlparse(service.device.device_url).netloc
         addr_family, local_host = await async_get_local_ip(device_host)
         port = self.listen_ports[addr_family]
 
@@ -134,13 +133,7 @@ class UpnpEventHandler:
     async def handle_notify(self, headers: Mapping[str, str], body: str) -> HTTPStatus:
         """Handle a NOTIFY request."""
         # ensure valid request
-        _LOGGER_TRAFFIC_UPNP.debug(
-            "Incoming request:\nNOTIFY\n%s\n\n%s",
-            "\n".join([key + ": " + value for key, value in headers.items()]),
-            body,
-        )
         if "NT" not in headers or "NTS" not in headers:
-            _LOGGER_TRAFFIC_UPNP.debug("Sending response: %s", HTTPStatus.BAD_REQUEST)
             return HTTPStatus.BAD_REQUEST
 
         if (
@@ -148,9 +141,6 @@ class UpnpEventHandler:
             or headers["NTS"] != "upnp:propchange"
             or "SID" not in headers
         ):
-            _LOGGER_TRAFFIC_UPNP.debug(
-                "Sending response: %s", HTTPStatus.PRECONDITION_FAILED
-            )
             return HTTPStatus.PRECONDITION_FAILED
 
         sid = headers["SID"]
@@ -165,7 +155,6 @@ class UpnpEventHandler:
                 body,
             )
 
-            _LOGGER_TRAFFIC_UPNP.debug("Sending response: %s", HTTPStatus.OK)
             return HTTPStatus.OK
 
         # decode event and send updates to service
@@ -181,7 +170,6 @@ class UpnpEventHandler:
         # send changes to service
         service.notify_changed_state_variables(changes)
 
-        _LOGGER_TRAFFIC_UPNP.debug("Sending response: %s", HTTPStatus.OK)
         return HTTPStatus.OK
 
     async def async_subscribe(
@@ -212,7 +200,7 @@ class UpnpEventHandler:
         headers = {
             "NT": "upnp:event",
             "TIMEOUT": "Second-" + str(timeout.seconds),
-            "HOST": urllib.parse.urlparse(service.event_sub_url).netloc,
+            "HOST": urlparse(service.event_sub_url).netloc,
             "CALLBACK": "<{}>".format(callback_url),
         }
         response_status, response_headers, _ = await self._requester.async_http_request(
@@ -260,7 +248,7 @@ class UpnpEventHandler:
         """Perform only a resubscribe, caller can retry subscribe if this fails."""
         # do SUBSCRIBE request
         headers = {
-            "HOST": urllib.parse.urlparse(service.event_sub_url).netloc,
+            "HOST": urlparse(service.event_sub_url).netloc,
             "SID": sid,
             "TIMEOUT": "Second-" + str(timeout.total_seconds()),
         }
@@ -364,7 +352,7 @@ class UpnpEventHandler:
 
         # do UNSUBSCRIBE request
         headers = {
-            "HOST": urllib.parse.urlparse(service.event_sub_url).netloc,
+            "HOST": urlparse(service.event_sub_url).netloc,
             "SID": sid,
         }
         response_status, response_headers, _ = await self._requester.async_http_request(
